@@ -228,17 +228,17 @@ public:
 	int maxFutureSupply;
 	int supply;
 	double time;
-	double REGEN_RATE;
-	vector<AssetStats> assetList;
 	vector<Entity> entityList;
 	vector<int> goalState;
 	vector<int> state;
 	bool done;
-	Names n;
+
+	static double REGEN_RATE;
+	static vector<AssetStats> assetList;
+	static Names n;
 
 	ProtossMacroEnv() {
 		REGEN_RATE = 1;
-		n = Names();
 		loadStatCatalog();
 		for (int i = 0; i < assetList.size(); i++) {
 			state.push_back(0);
@@ -261,8 +261,7 @@ public:
 		REGEN_RATE = env.REGEN_RATE;
 
 		//reload these from scratch for now
-		n = Names()
-		assetList = loadStatCatalog();
+		loadStatCatalog();
 
 		//deep copy
 		copyEntityList(env.entityList);
@@ -272,6 +271,7 @@ public:
 	}
 
 	void loadStatCatalog() {
+		if (assetList.size() > 0)return;
 		assetList = {
 			//placeholder
 			AssetStats(n.dummy, 0, 0, 0, 0, 0, n.dummy, { n.dummy }, 1, false),
@@ -348,7 +348,7 @@ public:
 	}
 
 	void initGoalState() {
-		for (size_t i = 0; i < assetList.size(); i++) {
+		for (int i = 0; i < assetList.size(); i++) {
 			goalState.push_back(0);
 		}
 		goalState[n.probe] = 14;
@@ -555,7 +555,7 @@ public:
 	int getNextComplete() {
 		double minCompleteTime = 10000;
 		int nextComplete = -1;
-		for (size_t i = 0; i < entityList.size(); i++) {
+		for (int i = 0; i < entityList.size(); i++) {
 			const Entity& e = entityList[i];
 			if (!e.isComplete && e.timeToComplete < minCompleteTime) {
 				minCompleteTime = e.timeToComplete;
@@ -568,7 +568,7 @@ public:
 
 	bool isDone() {
 		//check if entity counter >= goalstate
-		for (size_t i = 0; i < state.size(); i++) {
+		for (int i = 0; i < state.size(); i++) {
 			if (state[i] < goalState[i]) {
 				return false;
 			}
@@ -677,30 +677,9 @@ public:
 	}
 };
 
-class GeneralLoader
-{
-public:
-	vector<AssetStats> assetList;
-	Names n;
-
-	GeneralLoader() {
-		
-	}
-
-	//create an environment from here that will have references to this object
-	ProtossMacroEnv createFreshEnv() {
-		ProtossMacroEnv env = ProtossMacroEnv(n, assetList);
-		return env;
-	}
-
-	ProtossMacroEnv deepCopyEnv(ProtossMacroEnv& origEnv) {
-		ProtossMacroEnv env = ProtossMacroEnv(origEnv);
-		return env;
-	}
-
-	
-};
-
+Names ProtossMacroEnv::n;
+double ProtossMacroEnv::REGEN_RATE;
+vector<AssetStats> ProtossMacroEnv::assetList;
 
 namespace py = pybind11;
 
@@ -716,9 +695,13 @@ PYBIND11_MODULE(probotest1, m) {
 
     )pbdoc";
 
+	/*pybind11::class_<Test>(m, "Test")
+		.def(pybind11::init<>())
+		;*/
+
     pybind11::class_<ProtossMacroEnv>(m, "ProtossMacroEnv")
 		.def(pybind11::init<>())
-		.def(pybind11::init<const ProtossMacroEnv&>())
+		.def(pybind11::init<const ProtossMacroEnv&>(), "constuctor 2", pybind11::arg("env"))
         .def("step", &ProtossMacroEnv::step)
 		.def("reset", &ProtossMacroEnv::reset)
 		.def("getEntityList", &ProtossMacroEnv::getState)
